@@ -2,6 +2,8 @@ package org.gcube.portlets.user.td.resourceswidget.client;
 
 
 
+import org.gcube.portlets.user.td.gwtservice.shared.tr.resources.ResourceTDDescriptor;
+import org.gcube.portlets.user.td.resourceswidget.client.charts.ChartViewerDialog;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
 
 import com.allen_sauer.gwt.log.client.Log;
@@ -18,6 +20,8 @@ import com.google.web.bindery.event.shared.SimpleEventBus;
 public class ResourcesWidgetEntry  implements EntryPoint  {
 
 	
+	private ResourceTDDescriptor resourceTDDescriptor;
+
 	public void onModuleLoad() {
 		EventBus eventBus= new SimpleEventBus();
 	
@@ -27,9 +31,13 @@ public class ResourcesWidgetEntry  implements EntryPoint  {
 		trId.setId("7");
 		trId.setTableId("402");
 		
-		ResourcesDialog dialog=new ResourcesDialog(trId,eventBus);
-		dialog.show();
+		//ResourcesDialog dialog=new ResourcesDialog(trId,eventBus);
+		//dialog.show();
 		
+		resourceTDDescriptor=new ResourceTDDescriptor();
+		resourceTDDescriptor.setName("Test Chart");
+		ChartViewerDialog chartDialog=new ChartViewerDialog(resourceTDDescriptor, trId, eventBus, true);
+		chartDialog.show();
 		
 		Log.info("Hello!");
 	}
